@@ -41,7 +41,6 @@ class XBRLElement:
         except (TypeError, ValueError):
             if isinstance(value, str):
                 self.value = value.replace('\n', '')
-            logger.info(f"XBRLElement value convert to float failure for {self.value}")
 
         self.children = {}
         self.parent = None
@@ -153,13 +152,26 @@ class XBRLElement:
     def items(self):
         """
         A recursive function iterator allowing access to loop over the entire dataset as a list
-        :return: Yeilds  Uri, Label, Ref, Value
+        :return: Yields  Uri, Label, Ref, Value
         """
         yield self
         for child in self.children.keys():
             for ele in child.items():
                 yield ele
 
+    @lru_cache(maxsize=512)
+    def data(self):
+        """
+        A recursive function iterator returning all low level elements
+        :return: Yields XBRLElement
+        """
+        if all(child.value is not None and len(child.children) == 0 for child in self.children):
+            yield self
+
+        for child in self.children.keys():
+            for ele in child.data():
+                yield ele
+
     @lru_cache(maxsize=512)
     def to_json(self) -> dict:
         """
@@ -191,6 +203,8 @@ class XBRLAssembler:
     uri_re = re.compile(r'(?:lab_)?((us-gaap|source|dei|[a-z]{3,4})[_:][A-Za-z]{5,})', re.IGNORECASE)
 
     def __init__(self, *args, **kwargs):
+        logger.debug(f"Created Assembler (*args={args}, **kwargs={kwargs})")
+
         self.args = args
         self.kwargs = kwargs
 
@@ -289,31 +303,40 @@ class XBRLAssembler:
 
         return xbrl_assembler
 
-    def to_json(self, file_path):
+    def to_json(self, file_path, mode='w+'):
         """
         A write function to store all data in a json file
         :param file_path: A string to a file
         """
-        data = {}
-
-        if os.path.isfile(file_path):
-            with open(file_path, 'r') as file:
-                data = {uri: XBRLElement.from_json(dat) for uri, dat in json.load(file).items()}
-
-        for uri, header_ele in self.xbrl_elements.items():
-            if uri in data.keys():
-                for data_ele in header_ele.items():
-                    if all(child.value is not None and len(child.children) == 0 for child in data_ele.children):
-                        search = data[uri].search(data_ele.uri)
-                        if search:
-                            search.merge(data_ele)
-            else:
-                data[uri] = header_ele
-
-        with open(file_path, 'w+') as file:
-            file.write(json.dumps({uri: ele.to_json() for uri, ele in data.items()}, indent=4))
+        with open(file_path, mode) as file:
+            file.write(json.dumps({uri: ele.to_json() for uri, ele in self.xbrl_elements.items()}, indent=4))
             #json.dump({uri: ele.to_json() for uri, ele in data.items()}, file)
 
+    def merge(self, *others):
+        for other in others:
+            if other is self:
+                continue
+
+            if not isinstance(other, XBRLAssembler):
+                raise XBRLError(f"XBRLAssembler must merge with another XBRLAssembler not {type(other)}")
+
+            for uri, header_ele in self.xbrl_elements.items():
+                uri_prefix = uri.split('/')[-1]
+                uri_lookup = next((uri for uri in other.xbrl_elements.keys() if uri_prefix in uri), None)
+                if uri_lookup is None:
+                    logger.debug(f"Merge failed on document search (uri_prefix={uri_prefix})")
+                    continue
+
+                other_doc = other.xbrl_elements[uri_lookup]
+
+                for other_ele in other_doc.data():
+                    search_ele = header_ele.search(other_ele.uri)
+                    if search_ele:
+                        search_ele.merge(other_ele)
+                    else:
+                        logger.debug(f"Merge failed on element search (header_ele={header_ele}, other_ele={other_ele})")
+        return self
+
     def uri(self, raw):
         """
         Used to standardize uri's across mutliple documents
